Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'intern/cycles/blender/addon/properties.py')
-rw-r--r--intern/cycles/blender/addon/properties.py4
1 files changed, 3 insertions, 1 deletions
diff --git a/intern/cycles/blender/addon/properties.py b/intern/cycles/blender/addon/properties.py
index 840ab557132..26e1a6a223a 100644
--- a/intern/cycles/blender/addon/properties.py
+++ b/intern/cycles/blender/addon/properties.py
@@ -1467,9 +1467,11 @@ class CyclesPreferences(bpy.types.AddonPreferences):
devices.extend(cpu_devices)
return devices
# For backwards compatibility, only has CUDA and OpenCL.
def get_devices(self, compute_device_type=''):
cuda_devices = self.get_devices_for_type('CUDA')
+ self.get_devices_for_type('OPTIX')
opencl_devices = self.get_devices_for_type('OPENCL')
return cuda_devices, opencl_devices
@@ -1467,9 +1467,11 @@ class CyclesPreferences(bpy.types.AddonPreferences):
devices.extend(cpu_devices)
return devices
- # For backwards compatibility, only has CUDA and OpenCL.
+ # For backwards compatibility, only returns CUDA and OpenCL but still
+ # refreshes all devices.
def get_devices(self, compute_device_type=''):
cuda_devices = self.get_devices_for_type('CUDA')